clear all

fs = 1000; % Sampling Frequency
Ts = 1/fs; % Sampling period

% I. Define the simulink parameters
g = 1; % gain
T= 0.016; % time constant;
fc = 1/(2*pi*T); % the corresponding cutoff frequency

% II. Designing the sine wave input
f = 20; % fundamental frequency of the sine wave 
L = 10/f; % Simulation length = 10 periods

t = [1/fs:1/fs:L]'; % Time vector sampled at Ts
input = 10*sin (2*pi*f*t);

% III. use the "sim" function call to simulate LP_filter.mdl
TIMESPAN = [Ts L]; % start time = 0.001 (sec), end time = L (sec)
sim ('LP_filter',TIMESPAN);

%plot the input and its corresponding output.
figure, hold all, plot(t,input),plot(t,simout), title ('Input-Output Response')
legend ('input','output'),xlabel ('Time (sec)'), ylabel ('amplitude (deg/s)')

% Write the equivalent transfer function in Matlab to generate the bode
% plots.
Z = [];
P =[-1/T];
K = [g/T];
LP = zpk(Z,P,K,'Ts',0);

% Use "bode" to plot the bode plots.
FMIN = 0.01; FRES =.01; FMAX = 100;
fVect = FMIN:FRES:FMAX;
wVect = fVect.*(2*pi);
mag = zeros(length(fVect),1);
ph = zeros(length(fVect),1);
w = zeros(length(fVect),1);
[mag(:),ph(:),w(:)] = bode(LP,wVect); 
figure;
subplot(2,1,1)
loglog(fVect,mag)
ylabel('Amplitude');title('Magnitude Response')
subplot(2,1,2)
semilogx(fVect,ph)
ylabel('Phase (deg)');title('Phase Response')
xlabel('Frequency (deg/sec)')







